/*!\file convolutions.c
 *
 * \brief filtres de convolution adapts  SDL2
 * \author Fars BELHADJ, amsi@ai.univ-paris8.fr
 * \date February 13 2014
 */
#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <assert.h>

#include "convolutions.h"

/*!\brief ralise \a n fois un simple filtre de flou sur l'image
 * dcrite dans \a img. 
 *
 * Le flou ralis ici est de masque statique 3x3 contenant que des
 * 1. Il est  usage pdagogique.

 * \param img est la surface SDL dcrivant l'image, elle dot tre 4 bytes par pixel.
 * \param n est le nombre d'itrations de flou.
 */
void convSimpleBlur(SDL_Surface * img, int n) {
  int i, j, y, x;
  Uint32 * ppixels = img->pixels, * tpixels = NULL;
  Uint8 r, g, b;
  assert(img->format->BytesPerPixel == 4);
  tpixels = malloc(img->w * img->h * sizeof * tpixels);
  assert(tpixels);
  while(n-- > 0) {
    for(i = 0; i < img->h; i++) {
      for(j = 0; j < img->w; j++) {
	x = j;
	y = i;
	SDL_GetRGB(ppixels[(y * img->w + x)], img->format, &r, &g, &b);
	tpixels[(i * img->w + j)] = SDL_MapRGB(img->format, r, r, r);
      }
    }
    memcpy(ppixels, tpixels, img->w * img->h * sizeof * tpixels);
  }
  free(tpixels);
}
